@@ -2,39 +2,27 @@ import os
 import shutil
 import struct
 import zipfile
-from typing import Any, Optional
 
 import cloudscraper
 
+from subsearch.providers.generic import DownloadData
 from subsearch.utils import log, string_parser
 
 SCRAPER = cloudscraper.create_scraper(browser={"browser": "chrome", "platform": "android", "desktop": False})
 
 
-def download_zip(item: Any) -> None:
-    """
-    download zip file from url
-
-    Args:
-        item (str): url to download
-    """
-    file_path, url, current_num, total_num = item
-    log.output(f"Downloading: {current_num}/{total_num}")
-    r = SCRAPER.get(url, stream=True)
-    with open(file_path, "wb") as fd:
+def download_subtitle(data: DownloadData) -> int:
+    log.output(f"Downloading: {data.idx_num}/{data.idx_lenght}: {data.name}")
+    r = SCRAPER.get(data.url, stream=True)
+    with open(data.file_path, "wb") as fd:
         for chunk in r.iter_content(chunk_size=1024):
             fd.write(chunk)
 
+    return data.idx_num
+
 
-# extract all zip file in said directory
 def extract_files(cwd: str, extension: str) -> None:
-    """
-    extract all zip file in said directory that start with __subsearch__
-
-    Args:
-        cwd (str): directory to extract zip files from
-        extension (str): extension to extract
-    """
+    # extract all zip file in said directory
     subs_folder = os.path.join(cwd, "subs")
     if not os.path.exists(subs_folder):
         os.mkdir(subs_folder)
@@ -47,16 +35,8 @@ def extract_files(cwd: str, extension: str) -> None:
             zip_ref.close()
 
 
-# rename a .srts to the same as video release name
 def rename_best_match(release_name: str, cwd: str, extension: str) -> None:
-    """
-    rename the best matching srt file compared to the video file for e.g MPC-HC to auto import
-
-    Args:
-        release_name (str): name of the video name
-        cwd (str): current working directory
-        extension (str): suffix of the subtitle file
-    """
+    # rename a .srts to the same as video release name
     higest_value = (0, "")
     subs_folder = os.path.join(cwd, "subs")
     for file in os.listdir(subs_folder):
@@ -79,13 +59,6 @@ def rename_best_match(release_name: str, cwd: str, extension: str) -> None:
 
 # remove .zips
 def clean_up(cwd: str, extension: str) -> None:
-    """
-    Remove all the temporary files in the current working directory
-
-    Args:
-        cwd (str): current working directory
-        extension (str): suffix of the file to remove
-    """
     for file in os.listdir(cwd):
         if file.startswith("__subsearch__") and file.endswith(extension):
             log.output(f"Removing: {file}")
@@ -93,17 +66,19 @@ def clean_up(cwd: str, extension: str) -> None:
             os.remove(file_path)
 
 
+def write_not_downloaded_tmp(dst: str, not_downloaded: list) -> str:
+    file_dst = f"{dst}\\__subsearch__dl_data.tmp"
+    with open(file_dst, "w", encoding="utf8") as f:
+        for i in range(len(not_downloaded)):
+            name, _link = not_downloaded[i][1], not_downloaded[i][2]
+            link = _link.replace(" ", "")
+            f.writelines(f"{name} {link}")
+            f.write("\n")
+    return file_dst
+
+
 # get file hash
-def get_hash(file_path: str) -> Optional[str]:
-    """
-    Tries to get the hash of the file
-
-    Args:
-        file_path (str): path/filename to get the hash of
-
-    Returns:
-        str | Any: the hash of the file or None if the size is 0
-    """
+def get_hash(file_path: str) -> str | None:
     try:
         longlongformat = "<q"  # little-endian long long
         bytesize = struct.calcsize(longlongformat)
